@@ -42,16 +42,18 @@ def _generate_header(copyright_, f, options):
     if options.mode == 'partial':
         paragraph = (
             'Format: {}\n'
+            'Source: TODO\n'
             'Comment: *** only: {} ***'.format(
                 current_format, ', '.join(options.files)))
     elif copyright_:
         header = copyright_.header
         header.format = current_format
+        if not header.source:
+            header.source = 'TODO'
         paragraph = header.dump().rstrip('\n')
     else:
-        paragraph = 'Format: {}'.format(current_format)
+        paragraph = 'Format: {}\nSource: TODO'.format(current_format)
     print(paragraph, file=f)
-    print(file=f)
     if options.output:
         logging.debug('Generated header:\n%s', paragraph)
 
@@ -83,8 +85,8 @@ def generate_output(groups, filetree, copyright_, options):
 
             paragraph = group.copyright_block(options.glob)
 
-            print(paragraph, file=f)
             print(file=f)
+            print(paragraph, file=f)
 
             if options.output:
                 logging.debug('Generated group:\n%s', paragraph)
@@ -94,8 +96,8 @@ def generate_output(groups, filetree, copyright_, options):
             license_ = License.get(key)
             paragraph = str(license_)
 
-            print(paragraph, file=f)
             print(file=f)
+            print(paragraph, file=f)
 
             if options.output:
                 logging.debug('Generated license block:\n%s', paragraph)
