@@ -20,7 +20,11 @@
 
 import logging
 import os
-import re
+
+try:
+    import regex as re
+except ImportError:
+    import re
 
 try:
     from tqdm import tqdm
@@ -30,6 +34,8 @@ except ImportError:
             return a[0]
         return kw.get('iterable', None)
 
+from concurrent import futures
+
 from .datatypes import UNKNOWN, UNKNOWN_COPYRIGHTED
 from .parsers import parse_file
 
@@ -193,6 +199,7 @@ class FileInfo(object):
         logging.debug("Adding licenses %s, to %s", licenses, self)
         self.add_licenses(licenses)
         logging.debug("Resulted in %s", self.licenses)
+        return self
 
 
 class DirInfo(FileInfo):
@@ -202,6 +209,7 @@ class DirInfo(FileInfo):
         self.file_list = {}
         # Total number of files in sub tree
         self.total = 0
+        self.tasks = set()
 
     @property
     def parsed_license(self):
@@ -252,36 +260,28 @@ class DirInfo(FileInfo):
     def process_licenses(self, root, options):
         '''Scan the directory for license files.'''
 
-        known_license_filenames = (
-            r'^COPYING',
-            r'^COPYRIGHT$',
-            r'^LICENSE',
-        )
-
         dir_licenses = set()
         filenames = set()
 
-        for filename_re in known_license_filenames:
+        for task in futures.as_completed(self.tasks):
+            fileinfo = task.result()
+            if not fileinfo:
+                continue
+            licenses = fileinfo.licenses
+            if not licenses:
+                # Not a license?
+                continue
 
-            for name in self.file_list:
-                if not re.match(filename_re, name):
-                    continue
-                fileinfo = self.file_list[name]
-                if isinstance(fileinfo, DirInfo):
-                    continue
-                fileinfo.process_licenses(root, options)
-                licenses = fileinfo.licenses
+            dir_licenses.update(licenses)
+            filenames.add(fileinfo.fullname)
 
-                if not licenses:
-                    # Not a license?
-                    continue
-
-                dir_licenses.update(licenses)
-                filenames.add(fileinfo.fullname)
+        self.tasks = set()
 
         if dir_licenses:
             self.add_licenses(dir_licenses, filenames)
 
+        return self
+
 
 class RootInfo(DirInfo):
 
@@ -373,27 +373,57 @@ class RootInfo(DirInfo):
 
     def process(self, options):
         '''Iterate over the full tree processing their licenses.'''
-        seen = set()
-        for item in tqdm(self,
-                         desc='Processing',
-                         total=self.total,
-                         unit='file',
-                         dynamic_ncols=True,
-                         disable=(options.debug or not options.progress)):
+        kwargs = {}
+        if options.jobs:
+            kwargs['max_workers'] = options.jobs
 
-            if isinstance(item, DirInfo):
-                # Pre process COPYING files
-                item.process_licenses(self.root, options)
-                seen.update(item.license_filenames)
-                continue
+        known_license_filenames = (
+            r'^COPYING',
+            r'^COPYRIGHT$',
+            r'^LICENSE',
+        )
 
-            if not item.included:
-                continue
+        with futures.ThreadPoolExecutor(**kwargs) as executor:
+            tasks = set()
+            dirs_with_licenses = set()
 
-            if item.fullname in seen:
-                continue
+            for item in tqdm(self,
+                             desc='Queueing',
+                             total=self.total,
+                             unit='file',
+                             dynamic_ncols=True,
+                             disable=(options.debug or not options.progress)):
 
-            item.process_licenses(self.root, options)
+                if isinstance(item, DirInfo):
+                    continue
+
+                if not item.included:
+                    continue
+
+                task = executor.submit(item.process_licenses, self.root, options)
+
+                for filename_re in known_license_filenames:
+                    if not re.match(filename_re, item.name):
+                        continue
+                    item.parent.tasks.add(task)
+                    dirs_with_licenses.add(item.parent)
+                    break
+                else:
+                    tasks.add(task)
+
+            for dirinfo in dirs_with_licenses:
+                task = executor.submit(dirinfo.process_licenses, self.root,
+                                       options)
+                tasks.add(task)
+
+            done_iter = futures.as_completed(tasks)
+            for task in tqdm(done_iter,
+                             desc='Processing',
+                             total=len(tasks),
+                             unit='file',
+                             dynamic_ncols=True,
+                             disable=(options.debug or not options.progress)):
+                pass
 
 
 class FileGroup(object):
