@@ -51,6 +51,29 @@ class TestCopyright(unittest.TestCase):
         # An empty copyright file should yield no groups after processing
         self.assertEqual(copyright_.groups, [])
 
+    def testProcessIncomplete(self):
+        '''Parses a tree with an incomplete debian/copyright file.'''
+
+        copyright_, options = self._processTree('tests/testdata/incomplete')
+
+        # An incomplete copyright file should yield the incomplete groups after
+        # processing
+        expected_groups = [
+            {
+                'license': 'Unknown',
+                'holders': [],
+                'files':   ['debian/copyright'],
+                'comment': '',
+            },
+            {
+                'license': 'Unknown',
+                'holders': [],
+                'files':   ['test'],
+                'comment': '',
+            },
+        ]
+        self._checkSortedGroups(expected_groups, copyright_.groups, options)
+
     def testProcessSimple(self):
         '''Parses a debian/copyright with two entries (testdata/four).'''
 
@@ -60,25 +83,18 @@ class TestCopyright(unittest.TestCase):
             {
                 'license': 'LGPL-2+',
                 'holders': ['2014-2016, Maximiliano Curia <maxy@debian.org>'],
-                'files':   ['debian/compat', 'debian/copyright']
+                'files':   ['debian/compat', 'debian/copyright'],
+                'comment': '',
             },
             {
                 'license': 'GPL-2+',
                 'holders': ['2016, Jane Doe <janedoe@example.com>'],
-                'files':   ['test']
+                'files':   ['test'],
+                'comment': '',
             },
         ]
 
-        for i, group in enumerate(copyright_.groups):
-            key = group.get_key(options)
-            expected = expected_groups[i]
-            with self.subTest(msg='Checking "{}"'.format(key)):
-                self.assertEqual(
-                    list(group.copyrights.sorted_members()),
-                    expected['holders'])
-                self.assertEqual(group.license, expected['license'])
-                self.assertEqual(
-                    group.files.sorted_members(), expected['files'])
+        self._checkSortedGroups(expected_groups, copyright_.groups, options)
 
     def testProcessComplex(self):
         '''Parses a debian/copyright with many entries (testdata/three).'''
@@ -113,7 +129,10 @@ class TestCopyright(unittest.TestCase):
             },
         ]
 
-        for i, group in enumerate(copyright_.groups):
+        self._checkSortedGroups(expected_groups, copyright_.groups, options)
+
+    def _checkSortedGroups(self, expected_groups, groups, options):
+        for i, group in enumerate(groups):
             key = group.get_key(options)
             expected = expected_groups[i]
             with self.subTest(msg='Checking "{}"'.format(key)):
@@ -145,11 +164,11 @@ class TestCopyright(unittest.TestCase):
         self.longMessage = False
         for key in expected_groups:
             with self.subTest(msg='Checking "{}"'.format(key)):
-                self.assertTrue(key in groups,
+                self.assertIn(key, groups,
                                 msg='missing expected group: {}'.format(key))
         for key in groups:
             with self.subTest(msg='Checking "{}"'.format(key)):
-                self.assertTrue(key in expected_groups,
+                self.assertIn(key, expected_groups,
                                 msg='unexpected group: {}'.format(key))
         self.longMessage = True
 
@@ -180,8 +199,9 @@ class TestCopyright(unittest.TestCase):
             },
             ('GPL-2+', None, ''): {
                 'license': 'GPL-2+',
-                'holders': ['2016, Jane Doe <janedoe@example.com>'],
-                'files':   ['COPYING', 'src/main.py'],
+                'holders': ['1989-2003, Free Software Foundation, Inc',
+                            '2016, Jane Doe <janedoe@example.com>'],
+                'files':   ['COPYING', 'acinclude.m4', 'src/main.py'],
                 'comment': '',
             },
             ('MIT/X11', None, ''): {
@@ -247,7 +267,7 @@ class TestCopyright(unittest.TestCase):
             },
             ('GPL-2+', None, ''): {
                 'license': 'GPL-2+',
-                'holders': ['2016, Jane Doe <janedoe@example.com>'],
+                'holders': ['1989-2003, Free Software Foundation, Inc'],
                 'files':   [],
                 'comment': '',
             },
