@@ -47,7 +47,8 @@ class TestOutput(unittest.TestCase):
         err = _sys['stderr'].getvalue()
         self.assertFalse(len(err), 'Unexpected stderr: {}'.format(err))
         self.assertEqual(out, 'Format: https://www.debian.org/doc/'
-                         'packaging-manuals/copyright-format/1.0/\n\n',
+                         'packaging-manuals/copyright-format/1.0/\n'
+                         'Source: TODO\n',
                          'Unexpected stdout: {}'.format(out))
 
     def testEmptyPartial(self):
@@ -63,7 +64,8 @@ class TestOutput(unittest.TestCase):
         self.assertFalse(len(err), 'Unexpected stderr: {}'.format(err))
         self.assertEqual(out, 'Format: https://www.debian.org/doc/'
                          'packaging-manuals/copyright-format/1.0/\n'
-                         'Comment: *** only: . ***\n\n',
+                         'Source: TODO\n'
+                         'Comment: *** only: . ***\n',
                          'Unexpected stdout: {}'.format(out))
 
 
